import 'babel-polyfill';
import __ from 'lodash';
import {} from 'isomorphic-fetch';

const string = values => {
  return __.map(values, (value, key) =>
    encodeURIComponent(key) + '=' + encodeURIComponent(value)
  ).join('&');
};

const getHeader = (req) => {
  const headers = {
    'Content-Type': 'application/json'
  };

  if (req) {
    headers.cookie = req.get('cookie');
  }

  return {
    method: 'GET',
    headers: headers
  };
};

const postHeader = (values, req) => {
  const headers = {
    'Content-Type': 'application/json'
  };

  if (req) {
    headers.cookie = req.get('cookie');
  }

  return {
    method: 'POST',
    headers: headers,
    body: JSON.stringify( values )
  };
};


const deleteHeader = (values, req) => {
  const headers = {
    'Content-Type': 'application/json'
  };

  if (req) {
    headers.cookie = req.get('cookie');
  }

  return {
    method: 'DELETE',
    headers: headers,
    body: JSON.stringify( values )
  };
};

export default class ApiClient {
  constructor(req) {
    this.fetchJSON = ( url = '/', method = 'GET', values = {} ) => {

      return new Promise((resolve, reject) => {
        fetch( url +
              (method === 'GET' ? '?' + string(values) :
                                  ''),
              (method === 'GET' ? getHeader( req ) :
               method === 'POST' ? postHeader( values, req ) :
               method === 'DELETE' ? deleteHeader( values, req ) : ''))
               .then(res => {
                 if ( !res.ok ) {
                   res.json().then((json) => {
                     reject(json);
                   }, ()=>{
                     reject(res);
                   });
                 } else if ( method === 'GET' ) {
                   res.json().then((json) => {
                     resolve(json);
                   }, ()=>{
                     reject(res);
                   });
                 } else {
                   resolve({});
                 }
               }, ()=>{
                 reject(res);
               });
      });
    };
  }
}
